/* --- Vibrance settings --- */
varying highp vec2 textureCoordinate;

uniform sampler2D inputImageTexture;

#ifdef GL_FRAGMENT_PRECISION_HIGH
precision highp float;
#else
precision mediump float;
#endif

#define Vibrance 1.3  //Intelligently saturates (or desaturates if you use negative values) the pixels depending on their original saturation.





vec3 lerp(float a, vec4 b, float s)
{
    return vec3(a + (b - a) * s);
}
vec4 VibrancePass(in vec4 colorInput )
{
    
	vec4 color = colorInput; //original input color
    vec3 lumCoeff = vec3(0.2126, 0.7152, 0.0722);  //Values to calculate luma with
    
	float luma = dot(lumCoeff, color.rgb); //calculate luma (grey)
    
	float max_color = max(max(colorInput.r,colorInput.g),colorInput.b); //Find the strongest color
	float min_color = min(min(colorInput.r,colorInput.g),colorInput.b); //Find the weakest color
	
    float color_saturation = max_color - min_color; //The difference between the two is the saturation
    
    vec3 color3 = lerp(luma, color, (1.0 + (Vibrance * (1.0 - (sign(Vibrance) * color_saturation))))); //extrapolate between luma and original by 1 + (1-saturation)
    
	return vec4(color3.r,color3.g,color3.b,1.0); //return the result


}

void main()
{
    lowp vec4 textureColor = texture2D(inputImageTexture, textureCoordinate);
    lowp vec4 outputColor = VibrancePass(textureColor);
    
    gl_FragColor = outputColor;
}